PuzzleController class
- Inheritance
-
- Object
- ChangeNotifier
- PuzzleController
Constructors
- PuzzleController(PuzzleConfig config)
Properties
- config → PuzzleConfig
-
final
- continuousRotationController ↔ AnimationController
-
getter/setter pair
- currentPieceIndex ↔ int
-
getter/setter pair
-
fadeAnimation
↔ Animation<
double> -
getter/setter pair
- fadeController ↔ AnimationController
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- lottieController ↔ AnimationController
-
getter/setter pair
-
getter/setter pair
-
getter/setter pair
-
piecePositions
↔ List<
int> -
getter/setter pair
-
placedPieces
↔ List<
bool> -
getter/setter pair
-
revealedPieces
↔ List<
bool> -
getter/setter pair
-
rotationAnimation
↔ Animation<
double> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showCongratsAndPiece ↔ bool
-
getter/setter pair
- showLottieAnimation ↔ bool
-
getter/setter pair
- showPuzzleGame ↔ bool
-
getter/setter pair
- showPuzzlePiece ↔ bool
-
getter/setter pair
- showSideAnimations ↔ bool
-
getter/setter pair
- showUnlockScreen ↔ bool
-
getter/setter pair
-
sideAnimation
↔ Animation<
double> -
getter/setter pair
- sideAnimationController ↔ AnimationController
-
getter/setter pair
-
unlockFadeAnimation
↔ Animation<
double> -
getter/setter pair
- unlockFadeController ↔ AnimationController
-
getter/setter pair
-
unlockSlideAnimation
↔ Animation<
double> -
getter/setter pair
- unlockSlideController ↔ AnimationController
-
getter/setter pair
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
completePuzzle(
) → void -
dispose(
) → void -
Discards any resources used by the object.
override
-
initializeAnimations(
TickerProvider vsync) → void -
loadRevealedPieces(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
placePiece(
int slotIndex) → void -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
revealPiece(
) → void -
saveRevealedPieces(
) → Future< void> -
showUnlockScreenMethod(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited